[Libreoffice-commits] .: 2 commits - cppuhelper/Module_cppuhelper.mk sw/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Sat Oct 13 13:30:40 PDT 2012


 cppuhelper/Module_cppuhelper.mk |    4 ---
 sw/source/core/doc/docnew.cxx   |   28 ++++++++++----------------
 sw/source/core/doc/docnum.cxx   |   39 ++++++++++++++++++-------------------
 sw/source/core/doc/docsort.cxx  |   24 ++++++++++------------
 sw/source/core/doc/poolfmt.cxx  |   42 ++++++++++++++++++++--------------------
 5 files changed, 62 insertions(+), 75 deletions(-)

New commits:
commit 823bd50429a504de21c9a045e9da56b30cc0d97e
Author: Michael Stahl <mstahl at redhat.com>
Date:   Sat Oct 13 22:25:20 2012 +0200

    cppuhelper: remove obsolete comment

diff --git a/cppuhelper/Module_cppuhelper.mk b/cppuhelper/Module_cppuhelper.mk
index b28a863..b1d89b5 100644
--- a/cppuhelper/Module_cppuhelper.mk
+++ b/cppuhelper/Module_cppuhelper.mk
@@ -43,8 +43,4 @@ $(eval $(call gb_Module_add_check_targets,cppuhelper,\
 ))
 # CppunitTest_cppuhelper_qa_weak depends on module bridges
 
-# TODO ? (I don't think OOO_SUBSEQUENT_TESTS != "" can be true..
-# someone would have to do it on command line)
-#	qa/propertysetmixin/makefile.mk
-
 # vim: set noet sw=4 ts=4:
commit b61991ba2c9e7c59f7e34e8cfefaebfddb170e14
Author: Michael Stahl <mstahl at redhat.com>
Date:   Sat Oct 13 22:20:33 2012 +0200

    sw: tweak comment translations
    
    0413cc28 5513e24e d93196c8

diff --git a/sw/source/core/doc/docnew.cxx b/sw/source/core/doc/docnew.cxx
index 92b6edc..e036737 100644
--- a/sw/source/core/doc/docnew.cxx
+++ b/sw/source/core/doc/docnew.cxx
@@ -530,7 +530,7 @@ SwDoc::~SwDoc()
     delete pLayouter;
     pLayouter = 0L;
 
-    // Deactivate Undo notification from the Draw
+    // Deactivate Undo notification from Draw
     if( pDrawModel )
     {
         DrawNotifyUndoHdl();
@@ -558,7 +558,7 @@ SwDoc::~SwDoc()
             pLinkMgr->Remove( 0, pLinkMgr->GetLinks().size() );
     }
 
-    // The ChapterNumbers/Numbers need to be deleted before the Templates
+    // The ChapterNumbers/Numbers need to be deleted before the styles
     // or we update all the time!
     m_pNodes->pOutlineNds->clear();
     SwNodes & rUndoNodes( GetUndoManager().GetUndoNodes() );
@@ -603,12 +603,10 @@ SwDoc::~SwDoc()
     BOOST_FOREACH( SwSectionFmt* pFmt, *pSectionFmtTbl )
         lcl_DelFmtIndizes( pFmt );
 
-    // The formattings that come hereafter depend on the default formattings.
-    // [Destroy] these only after destroying the FmtIndices, because the content
+    // The formats/styles that follow depend on the default formats.
+    // Destroy these only after destroying the FmtIndices, because the content
     // of headers/footers has to be deleted as well. If in the headers/footers
     // there are still Flys registered at that point, we have a problem.
-    // (This comment might have been translated incorrectly. Blame the bad
-    // German original)
     BOOST_FOREACH(SwPageDesc *pPageDesc, aPageDescs)
         delete pPageDesc;
     aPageDescs.clear();
@@ -631,7 +629,7 @@ SwDoc::~SwDoc()
 
     // Optimization: Based on the fact that Standard is always 2nd in the
     // array, we should delete it as the last. With this we avoid
-    // remangling the Formats all the time!
+    // reparenting the Formats all the time!
     if( 2 < pTxtFmtCollTbl->size() )
         DeleteAndDestroy(*pTxtFmtCollTbl, 2, pTxtFmtCollTbl->size());
     DeleteAndDestroy(*pTxtFmtCollTbl, 1, pTxtFmtCollTbl->size());
@@ -641,8 +639,6 @@ SwDoc::~SwDoc()
             "DefaultGrfCollection must always be at the start" );
 
     DeleteAndDestroy(*pGrfFmtCollTbl, 1, pGrfFmtCollTbl->size());
-    // Is the result anyway - no _DEL array!
-    //  pGrfFmtCollTbl->Remove( 0, n );
     delete pGrfFmtCollTbl;
 
     /*
@@ -654,7 +650,6 @@ SwDoc::~SwDoc()
     pFrmFmtTbl->erase( pFrmFmtTbl->begin() );
     pCharFmtTbl->erase( pCharFmtTbl->begin() );
 
-    // Delete for pPrt
     DELETEZ( pPrt );
     DELETEZ( pNewDBMgr );
 
@@ -665,15 +660,14 @@ SwDoc::~SwDoc()
 
     // Only now destroy the Model, the drawing objects - which are also
     // contained in the Undo - need to remove their attributes from the
-    // Model. Also, DrawContacts could exist before that.
+    // Model. Also, DrawContacts could exist before this.
     ReleaseDrawModel();
     // Destroy DrawModel before the LinkManager, because it's always set
     // in the DrawModel.
     DELETEZ( pLinkMgr );
 
-    // Clear the Tables before deleting them, or we crash due to
-    // definition dependencies.
-    // We also convert the arrays (due to includes) to pointers.
+    // Clear the Tables before deleting the defaults, or we crash due to
+    // dependencies on defaults.
     delete pFrmFmtTbl;
     delete pSpzFrmFmtTbl;
 
@@ -802,7 +796,7 @@ void SwDoc::ClearDoc()
     GetIDocumentUndoRedo().DelAllUndoObj();
     ::sw::UndoGuard const undoGuard(GetIDocumentUndoRedo());
 
-    // Deactivate Undo notification from the Draw
+    // Deactivate Undo notification from Draw
     if( pDrawModel )
     {
         DrawNotifyUndoHdl();
@@ -830,7 +824,7 @@ void SwDoc::ClearDoc()
     SwPageDesc* pDummyPgDsc = aPageDescs[ nDummyPgDsc ];
 
     SwNodeIndex aSttIdx( *GetNodes().GetEndOfContent().StartOfSectionNode(), 1 );
-    // create the first one over and over again (without Attribute/Templates etc.
+    // create the first one over and over again (without attributes/style etc.
     SwTxtNode* pFirstNd = GetNodes().MakeTxtNode( aSttIdx, pDfltTxtFmtColl );
 
     if( pCurrentView )  //swmod 071029//swmod 071225
@@ -875,7 +869,7 @@ void SwDoc::ClearDoc()
 
     // Optimization: Based on the fact that Standard is always 2nd in the
     // array, we should delete it as the last. With this we avoid
-    // remangling the Formats all the time!
+    // reparenting the Formats all the time!
     if( 2 < pTxtFmtCollTbl->size() )
         DeleteAndDestroy(*pTxtFmtCollTbl, 2, pTxtFmtCollTbl->size());
     DeleteAndDestroy(*pTxtFmtCollTbl, 1, pTxtFmtCollTbl->size());
diff --git a/sw/source/core/doc/docnum.cxx b/sw/source/core/doc/docnum.cxx
index 67dee01..ecabe39 100644
--- a/sw/source/core/doc/docnum.cxx
+++ b/sw/source/core/doc/docnum.cxx
@@ -148,7 +148,7 @@ void SwDoc::SetOutlineNumRule( const SwNumRule& rRule )
     pOutlineRule->SetInvalidRule(sal_True);
     UpdateNumRule();
 
-    // update if we have foot notes && chapter-wise numbering
+    // update if we have foot notes && numbering by chapter
     if( !GetFtnIdxs().empty() && FTNNUM_CHAPTER == GetFtnInfo().eNum )
         GetFtnIdxs().UpdateAllFtn();
 
@@ -190,7 +190,7 @@ sal_Bool SwDoc::OutlineUpDown( const SwPaM& rPam, short nOffset )
     if( GetNodes().GetOutLineNds().empty() || !nOffset )
         return sal_False;
 
     // calculate the area
     const SwOutlineNodes& rOutlNds = GetNodes().GetOutLineNds();
     const SwNodePtr pSttNd = (SwNodePtr)&rPam.Start()->nNode.GetNode();
     const SwNodePtr pEndNd = (SwNodePtr)&rPam.End()->nNode.GetNode();
@@ -204,13 +204,13 @@ sal_Bool SwDoc::OutlineUpDown( const SwPaM& rPam, short nOffset )
     if( rOutlNds.Seek_Entry( pEndNd, &nEndPos ) )
         ++nEndPos;
 
     // We now have the wanted area in the OutlineNodes array,
     // so check now if we're not invalidating sublevels
     // (stepping over the limits)
     sal_uInt16 n;
 
     // Here we go:
-    // 1. Create the Template array:
+    // 1. Create the style array:
     SwTxtFmtColl* aCollArr[ MAXLEVEL ];
     memset( aCollArr, 0, sizeof( SwTxtFmtColl* ) * MAXLEVEL );
 
@@ -380,7 +380,7 @@ sal_Bool SwDoc::OutlineUpDown( const SwPaM& rPam, short nOffset )
         GetIDocumentUndoRedo().AppendUndo(pUndoOLR);
     }
 
-    // 2. Apply the new Template to all Nodes
+    // 2. Apply the new style to all Nodes
 
     n = nSttPos;
     while( n < nEndPos)
@@ -430,7 +430,7 @@ sal_Bool SwDoc::OutlineUpDown( const SwPaM& rPam, short nOffset )
 // Move up/down
 sal_Bool SwDoc::MoveOutlinePara( const SwPaM& rPam, short nOffset )
 {
-    // Do not move to special areas
+    // Do not move to special sections in the nodes array
     const SwPosition& rStt = *rPam.Start(),
                     & rEnd = &rStt == rPam.GetPoint() ? *rPam.GetMark()
                                                       : *rPam.GetPoint();
@@ -564,12 +564,11 @@ sal_Bool SwDoc::MoveOutlinePara( const SwPaM& rPam, short nOffset )
         return sal_False;
 
     OSL_ENSURE( aSttRg.GetIndex() > nNewPos || nNewPos >= aEndRg.GetIndex(),
-                "Position lies within MoveArea" );
+                "Position lies within Move range" );
 
-    // If a Position was calculated for the special area, we set it
-    // to document start instead.
-    // Areas or Tables at the document start will be moved to the
-    // back.
+    // If a Position inside the special nodes array sections was calculated,
+    // set it to document start instead.
+    // Sections or Tables at the document start will be pushed backwards.
     nNewPos = Max( nNewPos, GetNodes().GetEndOfExtras().GetIndex() + 2 );
 
     long nOffs = nNewPos - ( 0 < nOffset ? aEndRg.GetIndex() : aSttRg.GetIndex());
@@ -1741,10 +1740,10 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
     if( bIsOutlMv )
     {
         // For moving chapters (outline) the following reason will deny the move:
-        // if a start node is inside the moved area and its end node outside or vice versa.
+        // if a start node is inside the moved range and its end node outside or vice versa.
         // If a start node is the first moved paragraph, its end node has to be within the moved
         // area, too (e.g. as last node).
         // If an end node is the last node of the moved area, its start node has to be a part of
         // the moved section, too.
         pTmp1 = GetNodes()[ nStIdx ];
         if( pTmp1->IsStartNode() )
@@ -1765,7 +1764,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
         }
         pTmp1 = pTmp1->StartOfSectionNode();
         if( pTmp1->GetIndex() >= nStIdx )
-            return sal_False; // A start node which ends behind the moved area => no.
+            return sal_False; // A start node which ends behind the moved range => no.
     }
 
     sal_uLong nInStIdx, nInEndIdx;
@@ -1836,7 +1835,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
             aEndPos.nContent = pCNd ? pCNd->Len() : 1;
             sal_Bool bCheckDel = sal_True;
 
             // There is a some Redline Delete Object for the Area
             for( ; nRedlPos < GetRedlineTbl().size(); ++nRedlPos )
             {
                 const SwRedline* pTmp = GetRedlineTbl()[ nRedlPos ];
@@ -1859,7 +1858,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
                         break;
 
                     case POS_OUTSIDE:           // Pos2 is completely inside Pos1
-                    case POS_EQUAL:             // Pos1 is as big as Pos2
+                    case POS_EQUAL:             // Pos1 is equal to Pos2
                     case POS_OVERLAP_BEFORE:    // Pos1 overlaps Pos2 in the beginning
                     case POS_OVERLAP_BEHIND:    // Pos1 overlaps Pos2 at the end
                         return sal_False;
@@ -1871,7 +1870,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
 
     {
         // Send DataChanged before moving. We then can detect
         // which objects are still in the Area.
         // After the move they could come before/after the
         // Position.
         SwDataChanged aTmp( rPam );
@@ -1883,7 +1882,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
     SwRedline* pOwnRedl = 0;
     if( IsRedlineOn() )
     {
         // If the Area is completely in the own Redline, we can move it!
         sal_uInt16 nRedlPos = GetRedlinePos( pStt->nNode.GetNode(), nsRedlineType_t::REDLINE_INSERT );
         if( USHRT_MAX != nRedlPos )
         {
@@ -1891,7 +1890,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
             const SwPosition *pRStt = pTmp->Start(), *pREnd = pTmp->End();
             SwRedline aTmpRedl( nsRedlineType_t::REDLINE_INSERT, rPam );
             const SwCntntNode* pCEndNd = pEnd->nNode.GetNode().GetCntntNode();
             // Is completely in the Area and is the own Redline too?
             if( aTmpRedl.IsOwnRedline( *pTmp ) &&
                 (pRStt->nNode < pStt->nNode ||
                 (pRStt->nNode == pStt->nNode && !pRStt->nContent.GetIndex()) ) &&
@@ -190,7 +190,7 @@ sal_Bool SwDoc::OutlineUpDown( const SwPaM& rPam, short nOffset )
         return sal_False;
 
-    // calculate the area
+    // calculate the range
     const SwOutlineNodes& rOutlNds = GetNodes().GetOutLineNds();
     const SwNodePtr pSttNd = (SwNodePtr)&rPam.Start()->nNode.GetNode();
@@ -204,13 +204,13 @@ sal_Bool SwDoc::OutlineUpDown( const SwPaM& rPam, short nOffset )
         ++nEndPos;
 
-    // We now have the wanted area in the OutlineNodes array,
+    // We now have the wanted range in the OutlineNodes array,
     // so check now if we're not invalidating sublevels
     // (stepping over the limits)
@@ -1741,10 +1740,10 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
         // If a start node is the first moved paragraph, its end node has to be within the moved
-        // area, too (e.g. as last node).
-        // If an end node is the last node of the moved area, its start node has to be a part of
+        // range, too (e.g. as last node).
+        // If an end node is the last node of the moved range, its start node has to be a part of
         // the moved section, too.
         pTmp1 = GetNodes()[ nStIdx ];
@@ -1836,7 +1835,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
             sal_Bool bCheckDel = sal_True;
 
-            // There is a some Redline Delete Object for the Area
+            // There is a some Redline Delete Object for the range
             for( ; nRedlPos < GetRedlineTbl().size(); ++nRedlPos )
             {
@@ -1871,7 +1870,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
     {
         // Send DataChanged before moving. We then can detect
-        // which objects are still in the Area.
+        // which objects are still in the range.
         // After the move they could come before/after the
         // Position.
@@ -1883,7 +1882,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
     if( IsRedlineOn() )
     {
-        // If the Area is completely in the own Redline, we can move it!
+        // If the range is completely in the own Redline, we can move it!
         sal_uInt16 nRedlPos = GetRedlinePos( pStt->nNode.GetNode(), nsRedlineType_t::REDLINE_INSERT );
         if( USHRT_MAX != nRedlPos )
@@ -1891,7 +1890,7 @@ sal_Bool SwDoc::MoveParagraph( const SwPaM& rPam, long nOffset, sal_Bool bIsOutl
             SwRedline aTmpRedl( nsRedlineType_t::REDLINE_INSERT, rPam );
             const SwCntntNode* pCEndNd = pEnd->nNode.GetNode().GetCntntNode();
-            // Is completely in the Area and is the own Redline too?
+            // Is completely in the range and is the own Redline too?
             if( aTmpRedl.IsOwnRedline( *pTmp ) &&
                 (pRStt->nNode < pStt->nNode ||
diff --git a/sw/source/core/doc/docsort.cxx b/sw/source/core/doc/docsort.cxx
index 0f23d50..eb3e876 100644
--- a/sw/source/core/doc/docsort.cxx
+++ b/sw/source/core/doc/docsort.cxx
@@ -339,7 +339,7 @@ sal_Bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
         sal_uLong nStart = pStart->nNode.GetIndex(),
                         nEnd = pEnd->nNode.GetIndex();
         while( nStart <= nEnd )
-            // Iterate over a selected Area
+            // Iterate over a selected range
             if( !GetNodes()[ nStart++ ]->IsTxtNode() )
                 return sal_False;
     }
@@ -368,12 +368,12 @@ sal_Bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
                 pRedlUndo = new SwUndoRedlineSort( *pRedlPam,rOpt );
                 GetIDocumentUndoRedo().DoUndo(false);
             }
-            // First copy the area
+            // First copy the range
             SwNodeIndex aEndIdx( pEnd->nNode, 1 );
             SwNodeRange aRg( pStart->nNode, aEndIdx );
             GetNodes()._Copy( aRg, aEndIdx );
 
-            // Area is new from pEnd->nNode+1 to aEndIdx
+            // range is new from pEnd->nNode+1 to aEndIdx
             DeleteRedline( *pRedlPam, true, USHRT_MAX );
 
             pRedlPam->GetMark()->nNode.Assign( pEnd->nNode.GetNode(), 1 );
@@ -406,7 +406,7 @@ sal_Bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
     SwSortTxtElements aSortSet;
     while( aStart <= pEnd->nNode )
     {
-        // Iterate over a selected Area
+        // Iterate over a selected range
         SwSortTxtElement* pSE = new SwSortTxtElement( aStart );
         aSortSet.insert(pSE);
         aStart++;
@@ -750,7 +750,7 @@ void MoveCell(SwDoc* pDoc, const SwTableBox* pSource, const SwTableBox* pTar,
     aRg.aEnd = *pNd->EndOfSectionNode();
 
     // If the Target is empty (there is one empty Node)
-    // -> delete it and move the Target
+    // -> move and delete it
     SwNodeIndex aTar( *pTar->GetSttNd() );
     pNd = pDoc->GetNodes().GoNext( &aTar );     // next ContentNode
     sal_uLong nCount = pNd->EndOfSectionIndex() - pNd->StartOfSectionIndex();
@@ -815,20 +815,19 @@ FlatFndBox::~FlatFndBox()
 }
 
 /*--------------------------------------------------------------------
-    Description: All Lines of a Box need to have as many Boxes
+    Description: All Lines of a Box need to have same number of Boxes
  --------------------------------------------------------------------*/
 sal_Bool FlatFndBox::CheckLineSymmetry(const _FndBox& rBox)
 {
     const _FndLines &rLines = rBox.GetLines();
     sal_uInt16 nBoxes(0);
 
-    // Iterate over Lines
     for(sal_uInt16 i=0; i < rLines.size(); ++i)
-    {   // A List's Box
+    {
         const _FndLine* pLn = &rLines[i];
         const _FndBoxes& rBoxes = pLn->GetBoxes();
 
         // Amount of Boxes of all Lines is uneven -> no symmetry
         if( i  && nBoxes != rBoxes.size())
             return sal_False;
 
@@ -841,20 +840,19 @@ sal_Bool FlatFndBox::CheckLineSymmetry(const _FndBox& rBox)
 
 /*--------------------------------------------------------------------
     Description: Check Box for symmetry
-                 All Boxes of a Line need to have as many Lines
+                 All Boxes of a Line need to have same number of Lines
  --------------------------------------------------------------------*/
 sal_Bool FlatFndBox::CheckBoxSymmetry(const _FndLine& rLn)
 {
     const _FndBoxes &rBoxes = rLn.GetBoxes();
     sal_uInt16 nLines(0);
 
-    // Iterate over Boxes
     for(sal_uInt16 i=0; i < rBoxes.size(); ++i)
-    {   // The Boxes of a Line
+    {
         _FndBox const*const pBox = &rBoxes[i];
         const _FndLines& rLines = pBox->GetLines();
 
         // Amount of Boxes of all Lines is uneven -> no symmetry
         if( i && nLines != rLines.size() )
             return sal_False;
 
@@ -815,20 +815,19 @@ FlatFndBox::~FlatFndBox()
         const _FndBoxes& rBoxes = pLn->GetBoxes();
 
-        // Amount of Boxes of all Lines is uneven -> no symmetry
+        // Number of Boxes of all Lines is unequal -> no symmetry
         if( i  && nBoxes != rBoxes.size())
             return sal_False;
@@ -841,20 +840,19 @@ sal_Bool FlatFndBox::CheckLineSymmetry(const _FndBox& rBox)
         const _FndLines& rLines = pBox->GetLines();
 
-        // Amount of Boxes of all Lines is uneven -> no symmetry
+        // Number of Lines of all Boxes is unequal -> no symmetry
         if( i && nLines != rLines.size() )
             return sal_False;
diff --git a/sw/source/core/doc/poolfmt.cxx b/sw/source/core/doc/poolfmt.cxx
index 948df56..87527a2 100644
--- a/sw/source/core/doc/poolfmt.cxx
+++ b/sw/source/core/doc/poolfmt.cxx
@@ -106,7 +106,7 @@ static const sal_uInt16 aHeadlineSizes[ 2 * MAXLEVEL ] = {
 static long lcl_GetRightMargin( SwDoc& rDoc )
 {
     // Make sure that the printer settings are taken over to the standard
-    // page template
+    // page style
     const SwFrmFmt& rPgDscFmt = rDoc.GetPageDesc( 0 ).GetMaster();
     const SvxLRSpaceItem& rLR = rPgDscFmt.GetLRSpace();
     const long nLeft = rLR.GetLeft();
@@ -303,7 +303,7 @@ static void lcl_SetNumBul( SwDoc* pDoc, SwTxtFmtColl* pColl,
 // Return the AutoCollection by it's Id. If it doesn't
 // exist yet, create it.
 // If the String pointer is defined, then only query for
 // the Attribute descriptions. It doesn't create a template!
 SvxFrameDirection GetDefaultFrameDirection(sal_uLong nLanguage)
 {
     SvxFrameDirection eResult = (MsLangId::isRightToLeft( static_cast<LanguageType>(nLanguage)) ?
@@ -498,7 +498,7 @@ SwTxtFmtColl* SwDoc::GetTxtCollFromPool( sal_uInt16 nId, bool bRegardLanguage )
             break;
 
         case RES_POOLCOLL_GREETING:             // Greeting
-        case RES_POOLCOLL_REGISTER_BASE:        // Base directories
+        case RES_POOLCOLL_REGISTER_BASE:        // Base indexes
         case RES_POOLCOLL_SIGNATURE:            // Signatures
         case RES_POOLCOLL_TABLE:                // Tabele content
             {
@@ -539,7 +539,7 @@ SwTxtFmtColl* SwDoc::GetTxtCollFromPool( sal_uInt16 nId, bool bRegardLanguage )
             break;
 
 
-        // Special areas:
+        // Special sections:
         // Header
         case RES_POOLCOLL_HEADER:
         case RES_POOLCOLL_HEADERL:
@@ -584,7 +584,7 @@ SwTxtFmtColl* SwDoc::GetTxtCollFromPool( sal_uInt16 nId, bool bRegardLanguage )
             }
             break;
 
-        case RES_POOLCOLL_LABEL:                // Base label
+        case RES_POOLCOLL_LABEL:                // basic caption
             {
                 SvxULSpaceItem aUL( RES_UL_SPACE ); aUL.SetUpper( PT_6 ); aUL.SetLower( PT_6 );
                 aSet.Put( aUL );
@@ -596,13 +596,13 @@ SwTxtFmtColl* SwDoc::GetTxtCollFromPool( sal_uInt16 nId, bool bRegardLanguage )
             break;
 
         case RES_POOLCOLL_FRAME:                // Frame content
-        case RES_POOLCOLL_LABEL_ABB:            // Label projection
-        case RES_POOLCOLL_LABEL_TABLE:          // Label table
-        case RES_POOLCOLL_LABEL_FRAME:          // Label frame
-        case RES_POOLCOLL_LABEL_DRAWING:        // Label drawing
+        case RES_POOLCOLL_LABEL_ABB:            // caption image
+        case RES_POOLCOLL_LABEL_TABLE:          // caption table
+        case RES_POOLCOLL_LABEL_FRAME:          // caption frame
+        case RES_POOLCOLL_LABEL_DRAWING:        // caption drawing
             break;
 
-        case RES_POOLCOLL_JAKETADRESS:          // Jaket address
+        case RES_POOLCOLL_JAKETADRESS:          // envelope address
             {
                 SvxULSpaceItem aUL( RES_UL_SPACE ); aUL.SetLower( PT_3 );
                 aSet.Put( aUL );
@@ -625,7 +625,7 @@ SwTxtFmtColl* SwDoc::GetTxtCollFromPool( sal_uInt16 nId, bool bRegardLanguage )
             }
             break;
 
-        // User directories:
+        // User defined indexes:
         case RES_POOLCOLL_TOX_USERH:            // Header
             lcl_SetRegister( this, aSet, 0, sal_True, sal_False );
             {
@@ -664,7 +664,7 @@ SwTxtFmtColl* SwDoc::GetTxtCollFromPool( sal_uInt16 nId, bool bRegardLanguage )
             lcl_SetRegister( this, aSet, 9, sal_False, sal_True );
             break;
 
-        // Index directories
+        // Index
         case RES_POOLCOLL_TOX_IDXH:         // Header
             lcl_SetRegister( this, aSet, 0, sal_True, sal_False );
             {
@@ -685,7 +685,7 @@ SwTxtFmtColl* SwDoc::GetTxtCollFromPool( sal_uInt16 nId, bool bRegardLanguage )
             lcl_SetRegister( this, aSet, 0, sal_False, sal_False );
             break;
 
-        // Content directories
+        // Table of Content
         case RES_POOLCOLL_TOX_CNTNTH:       // Header
             lcl_SetRegister( this, aSet, 0, sal_True, sal_False );
             {
@@ -1445,7 +1445,7 @@ SwPageDesc* SwDoc::GetPageDescFromPool( sal_uInt16 nId, bool bRegardLanguage )
             return pNewPgDsc;
         }
 
     // Fault: unknown Pool template
     if( RES_POOLPAGE_BEGIN > nId ||  nId >= RES_POOLPAGE_END )
     {
         OSL_ENSURE( !this, "invalid Id" );
@@ -1491,7 +1491,7 @@ SwPageDesc* SwDoc::GetPageDescFromPool( sal_uInt16 nId, bool bRegardLanguage )
         break;
 
     case RES_POOLPAGE_FIRST:                // First page
-    case RES_POOLPAGE_REGISTER:             // Register
+    case RES_POOLPAGE_REGISTER:             // ToX
         {
             lcl_GetStdPgSize( this, aSet );
             aSet.Put( aLR );
@@ -1505,7 +1505,7 @@ SwPageDesc* SwDoc::GetPageDescFromPool( sal_uInt16 nId, bool bRegardLanguage )
         }
         break;
 
-    case RES_POOLPAGE_LEFT:                 // Link page
+    case RES_POOLPAGE_LEFT:                 // Left page
         {
             lcl_GetStdPgSize( this, aSet );
             aSet.Put( aLR );
@@ -1534,7 +1534,7 @@ SwPageDesc* SwDoc::GetPageDescFromPool( sal_uInt16 nId, bool bRegardLanguage )
         }
         break;
 
-    case RES_POOLPAGE_JAKET:                // Jaket
+    case RES_POOLPAGE_JAKET:                // envelope
         {
             aLR.SetLeft( 0 ); aLR.SetRight( 0 );
             aUL.SetUpper( 0 ); aUL.SetLower( 0 );
@@ -1625,7 +1625,7 @@ SwNumRule* SwDoc::GetNumRuleFromPool( sal_uInt16 nId )
             return pNewRule;
         }
 
     // Fault: unknown Pool template
     if( RES_POOLNUMRULE_BEGIN > nId ||  nId >= RES_POOLNUMRULE_END )
     {
         OSL_ENSURE( !this, "invalid Id" );
@@ -2294,7 +2294,7 @@ bool SwDoc::IsPoolPageDescUsed( sal_uInt16 nId ) const
     return !pNewPgDsc->GetInfo( aGetHt );
 }
 
 // See if the Paragraph/Character/Frame/Page Template is in use
 sal_Bool SwDoc::IsUsed( const SwModify& rModify ) const
 {
     // Check if we have dependent ContentNodes in the Nodes array
@@ -2312,11 +2312,11 @@ sal_Bool SwDoc::IsUsed( const SwNumRule& rRule ) const
     return bUsed;
 }
 
 // Look for the Template name's position. If it doesn't exist,
 // insert a anew
 sal_uInt16 SwDoc::SetDocPattern( const String& rPatternName )
 {
-    OSL_ENSURE( rPatternName.Len(), "no Document Template name" );
+    OSL_ENSURE( rPatternName.Len(), "no Document style name" );
 
     size_t nNewPos = aPatternNms.size();
     for(size_t n = 0; n < aPatternNms.size(); ++n)
@@ -303,7 +303,7 @@ static void lcl_SetNumBul( SwDoc* pDoc, SwTxtFmtColl* pColl,
 // exist yet, create it.
 // If the String pointer is defined, then only query for
-// the Attribute descriptions. It doesn't create a template!
+// the Attribute descriptions. It doesn't create a style!
 SvxFrameDirection GetDefaultFrameDirection(sal_uLong nLanguage)
 {
@@ -1445,7 +1445,7 @@ SwPageDesc* SwDoc::GetPageDescFromPool( sal_uInt16 nId, bool bRegardLanguage )
         }
 
-    // Fault: unknown Pool template
+    // error: unknown Pool style
     if( RES_POOLPAGE_BEGIN > nId ||  nId >= RES_POOLPAGE_END )
     {
@@ -1625,7 +1625,7 @@ SwNumRule* SwDoc::GetNumRuleFromPool( sal_uInt16 nId )
         }
 
-    // Fault: unknown Pool template
+    // error: unknown Pool style
     if( RES_POOLNUMRULE_BEGIN > nId ||  nId >= RES_POOLNUMRULE_END )
     {
@@ -2294,7 +2294,7 @@ bool SwDoc::IsPoolPageDescUsed( sal_uInt16 nId ) const
 }
 
-// See if the Paragraph/Character/Frame/Page Template is in use
+// See if the Paragraph/Character/Frame/Page style is in use
 sal_Bool SwDoc::IsUsed( const SwModify& rModify ) const
 {
@@ -2312,11 +2312,11 @@ sal_Bool SwDoc::IsUsed( const SwNumRule& rRule ) const
 }
 
-// Look for the Template name's position. If it doesn't exist,
+// Look for the style name's position. If it doesn't exist,
 // insert a anew
 sal_uInt16 SwDoc::SetDocPattern( const String& rPatternName )


More information about the Libreoffice-commits mailing list